

library(testthat)
library(fastai)
library(reticulate)
library(magrittr)
library(data.table)
library(ggplot2)
library(ggpubr)

test_check("fastai")

